Documentation
¶
Index ¶
- type Artifact
- type Cache
- type Crawler
- type FileCache
- type Helper
- type Hook
- type IViewer
- type Indexer
- type Pipeline
- type Profiler
- type ResourceApi
- func (this *ResourceApi) ClearFeed()
- func (this *ResourceApi) CreateEntryMetric()
- func (this *ResourceApi) CreateFeedEntry()
- func (this *ResourceApi) DeleteEntryMetric()
- func (this *ResourceApi) DeleteFeedEntry()
- func (this *ResourceApi) GetEntryMetric()
- func (this *ResourceApi) ReorderFeed()
- func (this *ResourceApi) UpdateEntryMetric()
- func (this *ResourceApi) UpdateFeedEntry()
- type Scenario
- type Sensor
- type Viewer
- func (this *Viewer) GetCurrentContext()
- func (this *Viewer) GetEnvironment()
- func (this *Viewer) GetGlobalIndicesForEntry()
- func (this *Viewer) GetGlobalIndicesForFeed()
- func (this *Viewer) GetMetrics()
- func (this *Viewer) GetMetricsForEntry()
- func (this *Viewer) GetMetricsForFeed()
- func (this *Viewer) GetMetricsStats()
- func (this *Viewer) GetStorages()
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Cache ¶
type Cache interface {
// Lock takes a key and returns the path where the file can be written to.
// Packer guarantees that no other process will write to this file while
// the lock is held.
//
// If the key has an extension (e.g., file.ext), the resulting path
// will have that extension as well.
//
// The cache will block and wait for the lock.
Lock(string) string
// Unlock will unlock a certain cache key. Be very careful that this
// is only called once per lock obtained.
Unlock(string)
// RLock returns the path to a key in the cache and locks it for reading.
// The second return parameter is whether the key existed or not.
// This will block if any locks are held for writing. No lock will be
// held if the key doesn't exist.
RLock(string) (string, bool)
// RUnlock will unlock a key for reading.
RUnlock(string)
}
Cache implements a caching interface where files can be stored for re-use between multiple runs.
type FileCache ¶
type FileCache struct {
CacheDir string
// contains filtered or unexported fields
}
FileCache implements a Cache by caching the data directly to a cache directory.
type Profiler ¶
type Profiler struct {
// contains filtered or unexported fields
}
func NewProfiler ¶
type ResourceApi ¶
type ResourceApi struct {
// contains filtered or unexported fields
}
func NewResourceApi ¶
func NewResourceApi(resourceManager interface{}) *ResourceApi
func (*ResourceApi) ClearFeed ¶
func (this *ResourceApi) ClearFeed()
func (*ResourceApi) CreateEntryMetric ¶
func (this *ResourceApi) CreateEntryMetric()
func (*ResourceApi) CreateFeedEntry ¶
func (this *ResourceApi) CreateFeedEntry()
func (*ResourceApi) DeleteEntryMetric ¶
func (this *ResourceApi) DeleteEntryMetric()
func (*ResourceApi) DeleteFeedEntry ¶
func (this *ResourceApi) DeleteFeedEntry()
func (*ResourceApi) GetEntryMetric ¶
func (this *ResourceApi) GetEntryMetric()
func (*ResourceApi) ReorderFeed ¶
func (this *ResourceApi) ReorderFeed()
func (*ResourceApi) UpdateEntryMetric ¶
func (this *ResourceApi) UpdateEntryMetric()
func (*ResourceApi) UpdateFeedEntry ¶
func (this *ResourceApi) UpdateFeedEntry()
type Viewer ¶
type Viewer struct {
}
func (*Viewer) GetCurrentContext ¶
func (this *Viewer) GetCurrentContext()
func (*Viewer) GetEnvironment ¶
func (this *Viewer) GetEnvironment()
func (*Viewer) GetGlobalIndicesForEntry ¶
func (this *Viewer) GetGlobalIndicesForEntry()
func (*Viewer) GetGlobalIndicesForFeed ¶
func (this *Viewer) GetGlobalIndicesForFeed()
func (*Viewer) GetMetrics ¶
func (this *Viewer) GetMetrics()
func (*Viewer) GetMetricsForEntry ¶
func (this *Viewer) GetMetricsForEntry()
func (*Viewer) GetMetricsForFeed ¶
func (this *Viewer) GetMetricsForFeed()
func (*Viewer) GetMetricsStats ¶
func (this *Viewer) GetMetricsStats()
func (*Viewer) GetStorages ¶
func (this *Viewer) GetStorages()
Click to show internal directories.
Click to hide internal directories.